@@ -27,7 +27,9 @@ from .account import get_historical_portfolio,      \
                      delete_symbols_from_watchlist, \
                      build_holdings,                \
                      build_user_profile,            \
-                     load_phoenix_account
+                     load_phoenix_account,          \
+                     withdrawl_funds_to_bank_account, \
+                     deposit_funds_to_robinhood_account
 
 from .authentication import login, \
                             logout
@@ -41,7 +43,8 @@ from .crypto import load_crypto_profile,        \
                     get_crypto_historicals
 
 from .export import export_completed_stock_orders, \
-                    export_completed_option_orders
+                    export_completed_option_orders,\
+                    export_completed_crypto_orders
 
 from .helper import request_get,      \
                     request_post,     \
@@ -49,7 +52,8 @@ from .helper import request_get,      \
                     request_document, \
                     update_session,   \
                     set_output,       \
-                    get_output                       
+                    get_output,       \
+                    filter_data                       
 
 from .markets import get_currency_pairs,                    \
                      get_markets,                           \
