@@ -1,11 +1,13 @@
 """Contains functions for getting information related to the user account."""
 import os
+from uuid import uuid4
 
 import robin_stocks.helper as helper
 import robin_stocks.profiles as profiles
 import robin_stocks.stocks as stocks
 import robin_stocks.urls as urls
 
+
 @helper.login_required
 def load_phoenix_account(info=None):
     """Returns unified information about your account.
@@ -45,7 +47,7 @@ def load_phoenix_account(info=None):
     """
     url = urls.phoenix()
     data = helper.request_get(url, 'regular')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 @helper.login_required
 def get_historical_portfolio(interval=None, span='week', bounds='regular',info=None):
@@ -79,7 +81,7 @@ def get_historical_portfolio(interval=None, span='week', bounds='regular',info=N
     }
     data = helper.request_get(url, 'regular', payload)
 
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 @helper.login_required
 def get_all_positions(info=None):
@@ -111,7 +113,7 @@ def get_all_positions(info=None):
     url = urls.positions()
     data = helper.request_get(url, 'pagination')
 
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -145,7 +147,7 @@ def get_open_stock_positions(info=None):
     payload = {'nonzero': 'true'}
     data = helper.request_get(url, 'pagination', payload)
 
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -176,7 +178,7 @@ def get_dividends(info=None):
     url = urls.dividends()
     data = helper.request_get(url, 'pagination')
 
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -238,7 +240,7 @@ def get_notifications(info=None):
     url = urls.notifications()
     data = helper.request_get(url, 'pagination')
 
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -265,7 +267,7 @@ def get_wire_transfers(info=None):
     """
     url = urls.wiretransfers()
     data = helper.request_get(url, 'pagination')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -292,6 +294,53 @@ def get_margin_calls(symbol=None):
     return(data)
 
 
+@helper.login_required
+def withdrawl_funds_to_bank_account(ach_relationship, amount, info=None):
+    """Submits a post request to withdraw a certain amount of money to a bank account.
+
+    :param ach_relationship: The url of the bank account you want to withdrawl the money to.
+    :type ach_relationship: str
+    :param amount: The amount of money you wish to withdrawl.
+    :type amount: float
+    :param info: Will filter the results to get a specific value.
+    :type info: Optional[str]
+    :returns: Returns a list of dictionaries of key/value pairs for the transaction.
+
+    """
+    url = urls.banktransfers()
+    payload = {
+        "amount": amount,
+        "direction": "withdraw",
+        "ach_relationship": ach_relationship,
+        "ref_id": str(uuid4())
+    }
+    data = helper.request_post(url, payload)
+    return(helper.filter_data(data, info))
+
+
+@helper.login_required
+def deposit_funds_to_robinhood_account(ach_relationship, amount, info=None):
+    """Submits a post request to deposit a certain amount of money from a bank account to Robinhood.
+
+    :param ach_relationship: The url of the bank account you want to deposit the money from.
+    :type ach_relationship: str
+    :param amount: The amount of money you wish to deposit.
+    :type amount: float
+    :param info: Will filter the results to get a specific value.
+    :type info: Optional[str]
+    :returns: Returns a list of dictionaries of key/value pairs for the transaction.
+
+    """
+    url = urls.banktransfers()
+    payload = {
+        "amount": amount,
+        "direction": "deposit",
+        "ach_relationship": ach_relationship,
+        "ref_id": str(uuid4())
+    }
+    data = helper.request_post(url, payload)
+    return(helper.filter_data(data, info))
+
 @helper.login_required
 def get_linked_bank_accounts(info=None):
     """Returns all linked bank accounts.
@@ -303,7 +352,7 @@ def get_linked_bank_accounts(info=None):
     """
     url = urls.linked()
     data = helper.request_get(url, 'results')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -320,7 +369,7 @@ def get_bank_account_info(id, info=None):
     """
     url = urls.linked(id)
     data = helper.request_get(url)
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -338,18 +387,22 @@ def unlink_bank_account(id):
 
 
 @helper.login_required
-def get_bank_transfers(info=None):
+def get_bank_transfers(direction=None, info=None):
     """Returns all bank transfers made for the account.
 
+    :param direction: Possible values are 'received'. If left blank, function will return all withdrawls and deposits \
+        that are initiated from Robinhood. If the value is 'received', funciton will return transfers intiated from \
+        your bank rather than Robinhood.
+    :type direction: Optional[str]
     :param info: Will filter the results to get a specific value. 'direction' gives if it was deposit or withdrawl.
     :type info: Optional[str]
     :returns: Returns a list of dictionaries of key/value pairs for each transfer. If info parameter is provided, \
     a list of strings is returned where the strings are the value of the key that matches info.
 
     """
-    url = urls.banktransfers()
+    url = urls.banktransfers(direction)
     data = helper.request_get(url, 'pagination')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 @helper.login_required
 def get_card_transactions(cardType=None, info=None):
@@ -369,7 +422,7 @@ def get_card_transactions(cardType=None, info=None):
 
     url = urls.cardtransactions()
     data = helper.request_get(url, 'pagination', payload)
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 @helper.login_required
 def get_stock_loan_payments(info=None):
@@ -383,7 +436,7 @@ def get_stock_loan_payments(info=None):
     """
     url = urls.stockloan()
     data = helper.request_get(url, 'pagination')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -398,7 +451,7 @@ def get_margin_interest(info=None):
     """
     url = urls.margininterest()
     data = helper.request_get(url, 'pagination')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -413,7 +466,7 @@ def get_subscription_fees(info=None):
     """
     url = urls.subscription()
     data = helper.request_get(url, 'pagination')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -428,7 +481,7 @@ def get_referrals(info=None):
     """
     url = urls.referral()
     data = helper.request_get(url, 'pagination')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -444,7 +497,7 @@ def get_day_trades(info=None):
     account = profiles.load_account_profile('account_number')
     url = urls.daytrades(account)
     data = helper.request_get(url, 'pagination')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -460,7 +513,7 @@ def get_documents(info=None):
     url = urls.documents()
     data = helper.request_get(url, 'pagination')
 
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -568,7 +621,7 @@ def get_all_watchlists(info=None):
     """
     url = urls.watchlists()
     data = helper.request_get(url, 'result')
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
@@ -592,7 +645,7 @@ def get_watchlist_by_name(name="My First List", info=None):
 
     url = urls.watchlists(name)
     data = helper.request_get(url,'list_id',{'list_id':watchlist_id})
-    return(helper.filter(data, info))
+    return(helper.filter_data(data, info))
 
 
 @helper.login_required
