@@ -4,6 +4,7 @@ import datetime
 import robin_stocks as r
 import pyotp
 import pytest
+from dateutil.relativedelta import relativedelta
 
 def third_friday(year, month, day):
     """Return datetime.date for monthly option expiration given year and
@@ -228,7 +229,7 @@ class TestStocks:
         event = r.get_events(self.single_stock)
         assert (len(event) == 0)
         event = r.get_events(self.event_stock)
-        assert (len(event) == 1)
+        assert (len(event) != 0)
         event = event[0]
         assert ('account' in event)
         assert ('cash_component' in event)
@@ -404,26 +405,35 @@ class TestOptions:
     totp  = pyotp.TOTP(os.environ['robin_mfa']).now()
     login = r.login(os.environ['robin_username'], os.environ['robin_password'], mfa_code=totp)
     #
-    now = datetime.datetime.now()
+    now = datetime.datetime.now() + relativedelta(months=1)
     expiration_date = third_friday(now.year, now.month, now.day).strftime("%Y-%m-%d")
     symbol = 'AAPL'
-    strike = round_up_price(symbol, 100)
+    strike = round_up_price(symbol, 10)
+
+    @classmethod
+    def setup_class(cls):
+        totp  = pyotp.TOTP(os.environ['robin_mfa']).now()
+        login = r.login(os.environ['robin_username'], os.environ['robin_password'], mfa_code=totp)
+
+    @classmethod
+    def teardown_class(cls):
+        r.logout()
 
     def test_find_tradable_options(self):
         info = r.find_options_by_expiration(self.symbol, self.expiration_date)
         first = info[0]
         assert (first['expiration_date'] == self.expiration_date)
-        assert (len(info) > 100)
+        assert (len(info) > 50)
         info = r.find_options_by_expiration(self.symbol, self.expiration_date, info='strike_price')
         first = info[0]
         assert (type(first) == str)
-        assert (len(info) > 100)
+        assert (len(info) > 50)
         info = r.find_options_by_expiration(self.symbol, self.expiration_date, info='expiration_date')
         assert (len(set(info)) == 1)
 
     def test_find_options_by_strike(self):
         info = r.find_options_by_strike(self.symbol, self.strike)
-        assert (len(info) > 30)
+        assert (len(info) >= 24)
         info = r.find_options_by_strike(self.symbol, self.strike,'call')
         assert (info[0]['type'] == 'call')
         info = r.find_options_by_strike(self.symbol, self.strike, info='expiration_date')
@@ -518,7 +528,7 @@ class TestMarkets:
         assert (float(first['price_movement']['market_hours_last_movement_pct']) < 0)
 
     def test_get_all_stocks_from_market_tag(self):
-        movers = r.get_all_stocks_from_market_tag('upcoming-earnings')
+        movers = r.get_all_stocks_from_market_tag('technology')
         assert (movers)
         first = movers[0]
         assert ('ask_price' in first)
@@ -675,7 +685,6 @@ class TestProfiles:
         assert ('eligible_for_fractionals' in profile)
         assert ('eligible_for_drip' in profile)
         assert ('eligible_for_cash_management' in profile)
-        assert ('eligible_for_trading_on_expiration' in profile)
         assert ('cash_management_enabled' in profile)
         assert ('option_trading_on_expiration_enabled' in profile)
         assert ('cash_held_for_options_collateral' in profile)
